@@ -92,7 +92,7 @@ class ClUpdateProfileAction(Action):
                                Get('cl_update_metadata_force') == 'force'))
               },
              {'name': 'eix_update',
-              'message': __("Updating the eix cache"),
+              'message': __("Updating the eix cache for {cl_repository_name}"),
               'method': 'Update.eixUpdate(cl_repository_name)',
               'condition': (
                   lambda Get: (Get('cl_update_outdate_set') == 'on' and
