@@ -78,7 +78,9 @@ class Wsdl(WsdlBase):
                                     'cl_update_wait_another_set',
                                     'cl_update_autocheck_schedule_set',
                                     'cl_update_binhost_recheck_set',
+                                    'cl_update_onedepth_set',
                                     'cl_update_cleanpkg_set',
+                                    'cl_update_check_rep_set',
                                     'cl_update_branch_data',
                                     'cl_templates_locate',
                                     'cl_verbose_set', 'cl_dispatch_conf'),
